==> istio-model-v1alpha3-6.6.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/IstioEgressListenerFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IstioEgressListenerFluent<A extends IstioEgressListenerFluent<A>> extends Fluent<A>{
  public String getBind();
  public A withBind(String bind);
  public Boolean hasBind();
  public CaptureMode getCaptureMode();
  public A withCaptureMode(CaptureMode captureMode);
  public Boolean hasCaptureMode();
  public A addToHosts(Integer index,String item);
  public A setToHosts(Integer index,String item);
  public A addToHosts(java.lang.String... items);
  public A addAllToHosts(Collection<String> items);
  public A removeFromHosts(java.lang.String... items);
  public A removeAllFromHosts(Collection<String> items);
  public List<String> getHosts();
  public String getHost(Integer index);
  public String getFirstHost();
  public String getLastHost();
  public String getMatchingHost(Predicate<String> predicate);
  public Boolean hasMatchingHost(Predicate<String> predicate);
  public A withHosts(List<String> hosts);
  public A withHosts(java.lang.String... hosts);
  public Boolean hasHosts();
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public Port getPort();
  public Port buildPort();
  public A withPort(Port port);
  public Boolean hasPort();
  public A withNewPort(String name,Integer number,String protocol,Integer targetPort);
  public IstioEgressListenerFluent.PortNested<A> withNewPort();
  public IstioEgressListenerFluent.PortNested<A> withNewPortLike(Port item);
  public IstioEgressListenerFluent.PortNested<A> editPort();
  public IstioEgressListenerFluent.PortNested<A> editOrNewPort();
  public IstioEgressListenerFluent.PortNested<A> editOrNewPortLike(Port item);
  public interface PortNested<N> extends Nested<N>,PortFluent<IstioEgressListenerFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/IstioEgressListenerFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IstioEgressListenerFluent<A extends IstioEgressListenerFluent<A>> extends Fluent<A>{
  public String getBind();
  public A withBind(String bind);
  public Boolean hasBind();
  public CaptureMode getCaptureMode();
  public A withCaptureMode(CaptureMode captureMode);
  public Boolean hasCaptureMode();
  public A addToHosts(int index,String item);
  public A setToHosts(int index,String item);
  public A addToHosts(java.lang.String... items);
  public A addAllToHosts(Collection<String> items);
  public A removeFromHosts(java.lang.String... items);
  public A removeAllFromHosts(Collection<String> items);
  public List<String> getHosts();
  public String getHost(int index);
  public String getFirstHost();
  public String getLastHost();
  public String getMatchingHost(Predicate<String> predicate);
  public Boolean hasMatchingHost(Predicate<String> predicate);
  public A withHosts(List<String> hosts);
  public A withHosts(java.lang.String... hosts);
  public Boolean hasHosts();
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public Port getPort();
  public Port buildPort();
  public A withPort(Port port);
  public Boolean hasPort();
  public A withNewPort(String name,Integer number,String protocol,Integer targetPort);
  public IstioEgressListenerFluent.PortNested<A> withNewPort();
  public IstioEgressListenerFluent.PortNested<A> withNewPortLike(Port item);
  public IstioEgressListenerFluent.PortNested<A> editPort();
  public IstioEgressListenerFluent.PortNested<A> editOrNewPort();
  public IstioEgressListenerFluent.PortNested<A> editOrNewPortLike(Port item);
  public interface PortNested<N> extends Nested<N>,PortFluent<IstioEgressListenerFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}
